package Acme::CPANAuthors::Japanese;

use strict;
use warnings;

our $VERSION = '0.220625';

use Acme::CPANAuthors::Register (
    ABUI      => 'DAISUKE ABUI',
    ACE       => 'yuichi tsunoda',
    ACIDLEMON => 'Masatoshi Kawazoe',
    ACOTIE    => 'Akiko Yokoyama',
    ADDSICT   => 'Yuuki Furuyama',
    ADOKOY    => 'Toshiaki Yokoda',
    AERDAN    => 'Kiyoshi Aman',
    AGREW     => 'Naoyuki Okumura',
    AHIGUCHI  => 'Akira Higuchi',
    AHIGUTI   => 'Akira Higuchi',
    AHIROSE   => 'Akira HIROSE',
    AINAME    => 'Satoshi Namai',
    AJIYOSHI  => 'yoichi ajiyoshi',
    AKIHIRO   => 'Kodai Takahashi',
    AKIHITO   => 'Akihito Takeda',
    AKIMACHO  => 'Akimasa Kimura',
    AKIRA     => 'Akira Hangai',
    AKITSUO   => 'Hiroaki Otsu',
    AKIYM     => 'Takumi Akiyama',
    AKOBA     => 'Atsushi Kobayashi',
    AKXLIX    => 'azuma, kuniyuki',
    AMARISAN  => 'Ryoji Tanida',
    AMIMOTO   => 'Aki Mimoto',
    ANATOFUZ  => 'Takahiro SHIMIZU',
    ANAZAWA   => 'Ryo Anazawa',
    ANNELI    => 'Yuki Izumi',
    ANZUSAN   => 'masashi nakajima',
    AONEKO    => 'Atsushi Watanabe',
    AOYAMA    => 'Yoichi Aoyama',
    AQL       => 'Tetsuya Toyoda',
    ARGRATH   => 'SHIRAKATA Kentaro',
    ARISAWA   => 'Kosuke Arisawa',
    ARUHI     => 'Ryota Miki',
    ARUTEIDO  => 'satoshi ishikawa',
    ASAKURA   => 'ASAKURA Takuji',
    ASARIH    => 'Hiro Asari',
    ASKADNA   => 'Shinichiro Aska',
    ASTJ      => 'Asato Wakisaka',
    AYANOKOUZ => 'AYANOKOUZI, Ryuunosuke',
    BANB      => 'ITO Nobuaki',
    BASHI     => 'Toshimasa Ishibashi',
    BAYASHI   => 'Dai Okabayashi',
    BAYSIDE   => 'Jun Shimizu',
    BOBPP     => 'Tadashi Matsuda',
    BOKUTIN   => 'Tomohiro Hosaka',
    BONAR     => 'Nakano Kyohei',
    BOXPHERE  => 'Satoshi Ohkubo',
    BWKIGPY   => 'Yoshifumi KODAMA',
    CASEY     => 'Keisuke Nagashima',
    CATATSUY  => 'KANEKO Tatsuya',
    CHIBA     => 'Masahiro Chiba',
    CLAIRVY   => 'NAGAYA Shinichiro',
    CLCL      => 'OONO Yoshitaka',
    CLICKTX   => 'Munenori Sugimura',
    CODEHEX   => 'Kei Kamikawa',
    COELA     => 'Satoshi Tamaki',
    COHTAN    => 'Kota Sakoda',
    CSIDE     => 'Hiroki Honda',
    DAEMONS   => 'MORI Shingo',
    DAIBA     => 'DAIBA, Keiichi',
    DAMEO     => 'Takashi Higashigata',
    DANJOU    => 'Nobuo Danjou',
    DANKOGAI  => 'Dan Kogai',
    DAYFLOWER => 'ITO Nobuaki',
    DELPHINUS => 'JINNOUCHI Yasushi',
    DENA      => 'DeNA  Co.,Ltd.',
    DGSCOPE   => 'Masayuki Komori',
    DMAKI     => 'Daisuke Maki',
    DOKECHIN  => 'Tetsuya Tatsumi',
    DRAWNBOY  => 'Hideaki Tanaka',
    DSYRTM    => 'Mitsuru Yasuda',
    EGAWATA   => 'Takashi Egawa',
    FIRSTJUN  => 'Jun Ito',
    FNOBI     => 'Fujisawa Shin',
    FUJIMURA  => 'FUJIMURA Yuki',
    FUJISAWA  => 'Mizuki Fujisawa',
    FUJIWARA  => 'Fujiwara Shunichiro',
    FUKATA    => 'Tatsuya Fukata',
    FUKUDA    => 'Keisuke Fukuda',
    FUKUMURA  => 'Akinori Fukumura',
    FUMIAKIY  => 'Fumiaki Yoshimatsu',
    FUTAYA    => 'Satoshi Futaya',
    GAOU      => 'Kazuharu Arakawa',
    GENKIST   => 'Genki Sato',
    GFUJI     => 'Goro Fuji',
    GOCCY     => 'Masaaki Goshima',
    GOLOGO    => 'Yohei Yamaguchi',
    GUCCHISK  => 'Satoshi Kobayashi',
    GUNYA     => 'GUNYARA-KUN',
    GURISUGI  => 'Takuya Sugimoto',
    HAAZIME   => 'Hajime Sueyoshi',
    HAKOBE    => 'Yohei Fushii',
    HAMANO    => 'Tsukasa Hamano',
    HANDLE    => 'NAGATA Hiroaki',
    HAOSAN    => 'Masafumi Yoshida',
    HAOYAYOI  => 'Soshi Tamura',
    HATA      => 'Masanori HATA',
    HATAK     => 'Hisashi HATAKEYAMA',
    HATENA    => 'Hatena',
    HATTORI   => 'Fumiaki Hattori',
    HATZ      => 'TSUGIHITO SHIBAHATA',
    HAYAJO    => 'Hayato Imai',
    HAYASHI   => 'Hiroo HAYASHI',
    HCH       => 'Hirokazu Chiba',
    HDAICHI   => 'daichi hiroki',
    HEDWIG    => 'Yusuke Sugiyama',
    HENTEKO   => 'Kenta Imai',
    HHORIUCHI => 'Hiroki Horiuchi',
    HIDE      => 'Hideo Kimura',
    HIDEAKIO  => 'Hideaki Ohno',
    HIDEDEN   => 'Hideyuki Kakiuchi',
    HIDEHIGO  => 'Akihide Higo',
    HIDEYUKI  => 'Hideyuki Ishiwata',
    HIGU      => 'Higuchi hiroyuki',
    HIKARINE  => 'Hajime Kurita',
    HIMACHOCO => 'Wataru Seto',
    HIMAZU    => 'Hideyo Imazu',
    HIO       => 'YAMASHINA Hio',
    HIRAFOO   => 'Tomoya Hirano',
    HIRAMATSU => 'Kazutake Hiramatsu',
    HIRATA    => 'HIRATA Yasuyuki',
    HIRATARA  => 'Masahiro Honma',
    HIRO      => 'hiroshi kitano',
    HIROBANEX => 'HIROYUKI AKABANE',
    HIROCUEKI => 'hiroshi ueki',
    HIROSE    => 'HIROSE Masaaki',
    HIROTAKA  => 'Hirotaka Honda',
    HIROYUKI  => 'Hiroyuki Yamanaka',
    HIROYUKIM => 'Yamanaka Hiroyuki',
    HISAICHI  => 'HISADA KAZUKI',
    HISAJU    => 'Kikumoto HIsatoshi',
    HITODE    => 'hitode 909',
    HIXI      => 'Hiroyoshi HOUCHI',
    HKOBA     => 'KOBAYASI, Hiroaki',
    HMATSU    => 'Hajime Matsumoto',
    HOKKE     => 'Yoichi Hirota',
    HOLLY     => 'Akira Horimoto',
    HOMESHIMA => 'Teppei Shimada',
    HORIMOTO  => 'Horimoto Yasuhiro',
    HORIUCHI  => 'Yasuhiro Horiuchi',
    HORIYUKI  => 'Yukio HORI',
    HOTO      => 'Yuki Ishikawa',
    HOTSU     => 'Hiroaki Otsu',
    HRK       => 'Haruka Kataoka',
    HRYK      => 'Hiroyuki Nakamura',
    HTK       => 'Hideaki Takahashi',
    HWAT      => 'WATANABE Hiroaki',
    ICHI      => 'Takuya Ichikawa',
    ICHIGOTAK => 'ichigotake',
    IHARA     => 'Ikuhiro IHARA',
    IIDAATCNT => 'MASAKATSU IIDA',
    IIZUKA    => 'Nao Iizuka',
    IKEBE     => 'IKEBE Tomohiro',
    IKENOX    => 'Naoto Ikeno',
    IKHRNET   => 'Tatsuya Ikehara',
    IKUTA     => 'Masahito Ikuta',
    ILLO      => 'Ichito Nagata',
    INA       => 'INABA Hitoshi',
    INABAJUN  => 'inaba jun',
    INFINITH  => 'Hiroshi Tashiro',
    INGKTDS   => 'Inagaki Tadashi',
    ISHIGAKI  => 'Kenichi Ishigaki',
    ISKATA    => 'Isao Katayama',
    ISOYA     => 'Ryohei Isoya',
    ISSM      => 'IWATA, Susumu',
    ITWARRIOR => 'Hitoshi Amano',
    IWAMATSU  => 'Nobuhiro Iwamatsu',
    IWATA     => 'Motonori Iwata',
    JAMADAM   => 'Sugama Keita',
    JERO      => 'Naoki Yaguchi',
    JIRO      => 'Jiro Nishiguchi',
    JKONDO    => 'Junya Kondo',
    JUDIOO    => 'Udo Oji',
    JUNBEAR   => 'Junko  Okuma',
    JUNICHIRO => 'Junichiro Tobe',
    JUNNAMA   => 'Junnama Noda',
    KAKUDRUMS => 'Yoichi Watanabe',
    KAMIOKA   => 'Nobuhiro Kamioka',
    KAMIPO    => 'Ryuta Kamizono',
    KAMO      => 'Yoshikazu Kamoshida',
    KAORUO    => 'Kaoru Oshita',
    KAORUOT   => 'Kaoru Oshita',
    KARUPA    => 'Kenta Sato',
    KASHIWABA => 'Nobuyuki Kashiwabara',
    KATAGIRI  => 'Tomoharu Katagiri',
    KATAOKA   => 'Hirofumi Kataoka',
    KAWABATA  => 'KAWABATA Kazumichi',
    KAWAMURAY => 'Yuto KAWAMURA',
    KAWASAKI  => 'Kawasaki Yusuke',
    KAZEBURO  => 'Masahiro Nagano',
    KAZUHISA  => 'KAZUHISA SUTO',
    KAZUHO    => 'Kazuho Oku',
    KAZUKIMA  => 'Kazuki MATSUDA',
    KAZUNORI  => 'Kazunori Minoda',
    KAZUPH    => 'Kazuhiro Homma',
    KAZYAM    => 'Kazumasa Yamamoto',
    KEISUKE   => 'Keisuke Kuramata',
    KEND      => 'Kenji Doi',
    KENJIRO   => 'Kenjiro Hirakawa',
    KENSHIN   => 'Kenshin YAMADA',
    KENTARO   => 'Kentaro Kuribayashi',
    KESIN     => 'Kenta Kase',
    KEYAMB    => 'YASUTAKE Kiyoshi',
    KFLY      => 'Kenta Kobayashi',
    KGA       => 'Wataru TOYA',
    KIMATA    => 'Tetsuya KIMATA',
    KIMOTO    => 'Yuki Kimoto',
    KIMURA    => 'Takeshi Kimura',
    KINSAN    => 'Hitoshi Yokozawa',
    KIRIRIMOD => 'Yuichi Kiri',
    KIRYUANZU => 'Fujiike Kyoka',
    KISEKI    => 'keita iseki',
    KITAK     => 'Keisuke Kita',
    KITAMAKI  => 'ryo kitamaki',
    KITANO    => 'dann',
    KIWANAMI  => 'Masashi Sakurai',
    KIZASHI   => 'Kizashi Nagata',
    KMIYAZAKI => 'Keitaro Miyazaki',
    KNAGANO   => 'Keiichiro Nagano',
    KNJSKYWKR => 'kenjiskywalker',
    KNOK      => 'NOKUBI Takatsugu',
    KOBAYASHI => 'Takeshi Kobayashi',
    KOBAYASI  => 'Hiroyuki Kobayasi',
    KOGA      => 'Seiki Koga',
    KOJIMAGI  => 'Koji Takiguchi',
    KOJIRO    => 'Kojiro ONO',
    KOJUN     => 'Kojun Ueno',
    KOKOGIKO  => 'OHTSUKA Ko-hei',
    KOMORIYA  => 'Kazunari Komoriya',
    KONA      => 'Kona Furugoori',
    KONBOI    => 'Ryosuke Yabuki',
    KONDO     => 'Yoshiyuki KONDO',
    KOPUG     => 'Masahiro Funakoshi',
    KOSEI     => 'Kosei Moriyama',
    KOSHITA   => 'Kaoru Oshita',
    KOYACHI   => 'Tsutomu Koyachi',
    KPEE      => 'Kiyoaki KATAKURA',
    KSAKANE   => 'sakane kenichi',
    KSUZUKI   => 'Ken Suzuki',
    KTAIGA    => 'Koji Taiga',
    KTAKATA   => 'Ken Takata',
    KTAT      => 'Kato Atsushi',
    KTMK      => 'ryo kita',
    KUBOTA    => 'Tomohiro KUBOTA',
    KUMA      => 'KUMAGAI Kentaro',
    KUMAKATSU => 'katsuki ookuma',
    KUNIWAK   => 'Yuki Kokubun',
    KUNIYOSHI => 'Kuniyoshi Kouji',
    KURAMAKO  => 'makoto',
    KURIHARA  => 'Yoshiki KURIHARA',
    KURIKIN   => 'Kazuhiro Yoshida',
    KURIYAMA  => 'Jun Kuriyama',
    KUZUHA    => 'Kuzuha SHINODA',
    KWATCH    => 'Makoto Kuwata',
    KWITKNR   => 'KAWAI, Takanori',
    KYANNY    => 'Kensuke Kaneko',
    KYO       => 'Kyo Nagashima',
    KYOKO     => 'N Kyoko',
    KYOMAIODP => 'Kyoma Takahashi',
    KYORO     => 'Kyosuke INOUE',
    KZFM      => 'Kazufumi Ohkawa',
    KZTOMITA  => 'Kazuyoshi Tomita',
    KZWMSYK   => 'Masayuki Kozawa',
    KZYS      => 'Kato Kazuyoshi',
    LAPIS     => 'Junichi Iwasaki',
    LAYSAKURA => 'Sho Nakatani',
    LIBITTE   => 'Nobuto Hachiya',
    LIMITUSUS => 'Tomoya KABE',
    LURKER    => 'Takumi KIMOTO',
    LUSHE     => 'Masatoshi Mizuno',
    LYOKATO   => 'Lyo Kato',
    MACOPY    => 'Makoto Taniwaki',
    MACOTASU  => 'Shiga Makoto',
    MAEDAMA   => 'Shuntaro Maeda',
    MAGICDRIV => 'Hiroshi IKEGAMI',
    MAHIRO    => 'Mahiro Ando',
    MAHITO    => 'Hogelist',
    MAHORI    => 'mahori',
    MAIDO     => 'Masahiro Funakoshi',
    MAKAMAKA  => 'Makamaka Hannyaharamitu',
    MAKOT     => 'Makoto Nozaki',
    MAKOTO    => 'Shin Honda',
    MALA      => 'ma la',
    MAND      => 'Yuki Manno',
    MANUOKADA => 'Manabu Okada',
    MAOE      => 'Mitsutoshi Aoe',
    MASAHITO  => 'Masahito Yoshida',
    MASAKI    => 'NAKAGAWA Masaki',
    MASAKYST  => 'MASAAKI SAITO',
    MASANORIH => 'Masanori Hara',
    MASAO     => 'Masao Kitamura',
    MASAP     => 'Masahiro Funakoshi',
    MASARTZ   => 'Masaru Hoshino',
    MASASHI   => 'masashi ogawa',
    MASASUZU  => 'SUZUKI Masashi',
    MASAWADA  => 'Masayoshi Wada',
    MASH      => 'Masakazu Ohtsuka',
    MASIUCHI  => 'Masahiro Iuchi',
    MASUTARO  => 'Kotaro MASUDA',
    MATSUMOTO => 'syushi matsumoto',
    MATTN     => 'Yasuhiro Matsumoto',
    MATZ      => 'Taichi Matsumura',
    MERU      => 'meru_akimbo',
    METEOR    => 'Shumpei URABE',
    MIHYAERU  => 'Atsushi Takano',
    MIKAGE    => 'SANO Taku',
    MIKI      => 'Takeshi Miki',
    MIKIHOSHI => 'KAN Fushihara',
    MIKIO     => 'Mikio Hirabayashi',
    MILANO    => 'Tsukui Akihiro',
    MINORU    => 'KAWAMOTO Minoru',
    MIXI      => 'mixi, Inc.',
    MIYAGAWA  => 'Tatsuhiko Miyagawa',
    MIYAMUKO  => 'MIYAMUKO Katsuyuki',
    MIYAZAKI  => 'Ittetsu Miyazaki',
    MIZZY     => 'Gosuke Miyashita',
    MNACAMURA => 'Mitsuhiro Nakamura',
    MONMON    => 'Nobuo Kumagai',
    MORIYA    => 'Moriya Masaki',
    MOSA      => 'Yusuke Enomoto',
    MOTEMEN   => 'motemen',
    MOTI      => 'Motohiko Abe',
    MOZNION   => 'Taiki Kawakami',
    MRMT      => 'Jun Morimoto',
    MSASASAKI => 'Masafumi Sasaki',
    MSHIGE    => 'shigeharu matsumoto',
    MUGENKEN  => 'Mugen Kenichi',
    MUGIFLY   => 'Masanori Ohgita',
    MURATA    => 'Shingo Murata',
    MURATAYA  => 'MURATA Yasuhisa',
    MUTO      => 'Nao Muto',
    MUYOSHI   => 'Mutsutoshi Yoshimoto',
    MYB       => 'Masayuki Iwai',
    MYFINDER  => 'TatsuroHisamori',
    MYUJI     => 'Yuji Maeda',
    NABESHIMA => 'Masaaki NABESHIMA',
    NAGAMI    => 'Shuhei Nagami',
    NAGATA    => 'Ichito Nagata',
    NAHCNUJ   => 'Junichi Hayashi',
    NAITO     => 'Naoyuki Ito',
    NAKAMURA  => 'makoto nakamura',
    NAKASHIN  => 'Shinji Nakamura',
    NAKAYAMA  => 'Yasuhiro Nakayama',
    NANTO     => 'nanto_vi (TOYAMA Nao)',
    NANZOU    => 'Takaaki Mizuno',
    NAOHIRO   => 'Naoya Hirota',
    NAOKIURAI => 'Naoki URAI',
    NAOY      => 'Naoyuki Ito',
    NAOYA     => 'Naoya Ito',
    NAOYAT    => 'Naoya "naochan" Tozuka',
    NAOYU     => 'Naoyuki Ito',
    NAOYUKI   => 'Naoyuki Ito',
    NARAZAKA  => 'N Narazaka',
    NARIPON   => 'nari',
    NARITOSHI => 'Naritoshi Hayashi',
    NARUSE    => 'NARUSE, Yui',
    NEJIGANE  => 'Yu Nejigane',
    NEKOKAK   => 'Atsushi Kobayashi',
    NEKOYA    => 'Ryo Miyake',
    NEZUMI    => 'IKEDA Soji',
    NGS       => 'Atsushi NAGASE',
    NISHIGAYA => 'NISHIGAYA, Yuki',
    NISHIKAWA => 'Kazuhiro Nishikawa',
    NOBJAS    => 'noblejasper',
    NODAJUN   => 'JUNICHI NODA',
    NOGUCHI   => 'Tatsuya Noguchi',
    NORAYUNI  => 'Takahito Yamatoya',
    NORITAKA  => 'Noritaka Okabe',
    NOZZZZZ   => 'Tetsunari Nozaki',
    NTAKANASI => 'Nao Takanashi',
    NTSUTSUMI => 'Naoya Tsutsumi',
    NUKOSUKE  => 'nuko suke',
    NUKOTANU  => 'Yoshiyasu Katayama',
    NYAGAO    => 'Takahiro Nagao',
    NYARLA    => 'Naoki Okamura',
    OCEORA    => 'eisaku ando',
    OGASAWARA => 'leann ogasawara',
    OGATA     => 'OGATA Tetsuji',
    OGAWA     => 'Hirotaka Ogawa',
    OINUME    => 'Kazuhiro Oinuma',
    OISHI     => 'Eisuke Oishi',
    OKAMUUU   => 'Masao Okamura',
    OKAWARI   => 'okawara ayato',
    OKAZUDM   => 'Kazuma Okada',
    OKLAHOMER => 'Go Hagiwara',
    OMOHAYUI  => 'Yui Takeuchi',
    ONISHI    => 'Yasuhiro Onishi',
    OPPARA    => 'oppara',
    OSDAKIRA  => 'Akira Osada',
    OUEST     => 'Daisuke NISHISAKA',
    OVERLAST  => 'Toshinori Sato',
    OYAMA     => 'Hiroyuki OYAMA',
    OZAWA     => 'OZAWA Sakuro',
    PAINA     => 'SATO Taisuke',
    PAPIX     => 'Takayuki Fukumoto',
    PAWAPAWA  => 'Kohei Yoshioka',
    PEN       => 'Abe Masahiro',
    PERFORB   => 'Yusuke Maeda',
    PIA       => 'Michiya Honda',
    PIROLIX   => 'Hiroyuki UENISHI',
    POCKET    => 'Masato Sogame',
    POKUTUNA  => 'POKUDA Tunahiko',
    POPPEN    => 'Shinsuke Matsui',
    PROGRHYME => 'IKEDA Kiyoshi',
    PUNYTAN   => 'punipuni',
    QAZXSWEDC => 'hiroshi morimoto',
    QBTCFAHX  => 'Naoki SUDA',
    QUEEN     => 'Yasuhiro Miyazaki',
    RIMFS     => 'Yuichiro Tanaka',
    RINSATO   => 'takashi sato',
    RINTARO   => 'Rintaro Ishizaki',
    RISOU     => 'Masaaki FUJISAWA',
    RITOU     => 'Ryo Ito',
    RIYWO     => 'Ryosuke IWANAGA',
    ROCKBONE  => 'Tooru Tsurukawa',
    ROZARY    => 'Syunsuke Fujishiro',
    RYM       => 'Takayuki Murakami',
    RYMIZUKI  => 'ryo iinuma',
    RYO       => 'Ryo Utsunomiya',
    RYOCHIN   => 'Okamoto RYO',
    RYOPEKO   => 'Ryoichi SEKIGUCHI',
    RYUNOSUKE => 'Ryunosuke Murakami',
    SADAHIRO  => 'SADAHIRO Tomoyuki',
    SAITORYC  => 'Ryoichi Saito',
    SASAKURE  => 'Kei Shimada (sasakure_kei)',
    SASAO     => 'SASAO Takahiro',
    SASARON   => 'Katsuhiro Sasaki',
    SASATA    => 'Tatsuya "sasata299" Sasaki',
    SASAZUKA  => 'Seiji Sasazuka',
    SATETSU   => 'shotaro akiyama',
    SATOH     => 'cho45 (SATOH, Hiroh)',
    SATOSIN   => 'Shinichiro Sato',
    SATZZ     => 'Akihiko SATODA',
    SAWAMUR   => 'Masaki  Sawamura',
    SAYANO    => 'Satoru Yano',
    SEAGIRL   => 'Takuho Yoshizu',
    SEI       => 'Shinichiro Sei',
    SEKIA     => 'Koichi SATOH',
    SEKIKN    => 'Kengo Seki',
    SEKIMURA  => 'Masayoshi Sekimura',
    SERA      => 'Kazuhiro Sera',
    SEYN      => 'Yasushi Nakajima',
    SHARADA   => 'Seiji Harada',
    SHARP     => 'Motoki Kondo',
    SHEERCAT  => 'tomoo amano',
    SHIBAZAKI => 'Yuki Shibazaki',
    SHIBUYA   => 'Kazuhiro Shibuya',
    SHIGETA   => 'Takatsugu Shigeta',
    SHIGIO    => 'Shigio Yamaguchi',
    SHIKONO   => 'Shinji KONO',
    SHIMAZU   => 'Yuki SHIMAZU',
    SHIMI     => 'Kazuhito Shimizu',
    SHINCHIT  => 'Takahiro Shinchi',
    SHINGT    => 'Shinichi Goto',
    SHINJI    => 'shinji kakimoto',
    SHINPEI   => 'HAYASHI, Shinpei',
    SHIRAIWA  => 'Kazuma Shiraiwa',
    SHMAEDA   => 'Shunsuke Maeda',
    SHMORIMO  => 'Shigeki Morimoto',
    SHOGO     => 'Shogo Ichinose',
    SHOHEIK   => 'Shohei Kameda',
    SHOJIKAI  => 'Shoji Kai',
    SHOT      => 'Shota Takayama',
    SIXEIGHT  => 'Tomohiro Nishimura',
    SKAJI     => 'Shoichi Kaji',
    SKJM      => 'Shin Kojima',
    SKONNO    => 'Satoshi Konno',
    SKUBOTA   => 'Satoshi KUBOTA',
    SKYFIVE   => 'Takeshi Ohishi',
    SMOMOT    => 'Seiji Momoto',
    SNGJOKEN  => 'Shingo Kikugawa',
    SNUMANO   => 'Shugo Numano',
    SOENO     => 'Kazumichi Soeno',
    SOH       => 'Soh Kitahara',
    SOHASHI   => 'Sean Ohashi',
    SOJIRO    => 'Taishi Hiraga',
    SONGMU    => 'Masayuki Matsuki',
    SOTSA     => 'Shinichiro Sato',
    SPRINGMT  => 'Makoto Haruyama',
    SSEI      => 'Shinichiro Sei',
    SSHIN     => 'Shintaro Seki',
    STAKASHIO => 'Shin Takashio',
    SUENAGA   => 'Hiroki Suenaga',
    SUGA      => 'suga masashi',
    SUGASUGAX => 'sugawara taiki',
    SUGMAK    => 'Makoto Sugiyama',
    SUGYAN    => 'Yoshihiro Sugi',
    SUHARA    => 'Yoshihiko Suhara',
    SUZUKI    => 'Yuji Suzuki',
    SYAGI     => 'Satoshi Yagi',
    SYNCLOVER => 'Naoya Sato',
    SYOHEX    => 'Syohei Yoshida',
    SYSCAT    => 'Makoto Sasaki',
    SYSTEMS   => 'Ken Suzuki',
    SZARATE   => 'Santiago Zarate',
    TABAYASHI => 'Tetsuya Tabayashi',
    TAC       => 'Takuya Iida',
    TADOKORO  => 'hiroshi tadokoro',
    TAGOMORIS => 'Satoshi Tagomori',
    TAILRIVER => 'Shinsuke Ogawa',
    TAIY      => 'Taisuke Yamada',
    TAIYOH    => 'Taiyoh Tanaka',
    TAKAHITO  => 'Takahito Yamada',
    TAKANORI  => 'Takanori Uzuka',
    TAKASAGO  => 'Masaaki Takasago',
    TAKASH    => 'shuhei takahashi',
    TAKASHI   => 'Takashi Saeki',
    TAKAYUKI  => 'Takayuki Ikeda',
    TAKEASH   => 'Takehiko Shintani',
    TAKEBAYAS => 'Shun Takebayashi',
    TAKEFUMI  => 'KIMURA, takefumi',
    TAKEO     => 'Takeo Suzuki',
    TAKERU    => 'Takeru INOUE',
    TAKESAKO  => 'Yoshinori TAKESAKO',
    TAKESHI   => 'tee wada',
    TAKESHIGE => 'Ken Takeshige',
    TAKESHUN  => 'Shun Takeyama',
    TAKIMO    => 'Shinya Takimoto',
    TAKITAHA  => 'Takeshi Kitahara',
    TAKKYUN   => 'Takayuki Ikeda',
    TAKUJI    => 'Nishibayashi Takuji',
    TAKUMI    => 'Takumi Hayashi',
    TAKUYAA   => 'Takuya Asano',
    TAMAKOTO  => 'Tanaka Makoto',
    TAMASHIRO => 'Yuji Tamashiro',
    TANABE    => 'Hisao Tanabe',
    TANAKA    => 'Tanaka Tatsuya',
    TANIGUCHI => 'Koichi Taniguchi',
    TANIMOTO  => 'Satoshi Tanimoto',
    TARAO     => 'INA Lintaro',
    TARO      => 'Daisuke Komatsu',
    TAROK     => 'Taro Kawagishi',
    TATE      => 'tateisu',
    TATENO    => 'Yuichi Tateno',
    TATSUYAGI => 'Tatsuya Yagi',
    TAWAN     => 'Taro Funaki',
    TAWANYAN  => 'Hiroki Nishino',
    TAWASHI   => 'Hiroki Nishino',
    TEBORA    => 'Issei Horie',
    TENMIHI   => 'Kenichi Murao',
    THORIKAWA => 'Takahiro Horikawa',
    TISHIDUKA => 'Takeshi ISHIDUKA',
    TITSUKI   => 'Itsuki Toyota',
    TKURITA   => 'Tetsuro KURITA',
    TKZWTKS   => 'Takashi Takizawa',
    TMAESAKA  => 'Toru Maesaka',
    TMITOH    => 'Tomoaki Itoh',
    TMITZ     => 'Tomohiro Mitsumune',
    TNAGA     => 'Tomohide Nagasima',
    TNANBA    => 'NANBA Toshiaki',
    TNISHINO  => 'Taro Nishino',
    TOAMANO   => 'Tomoo Amano',
    TOCIYUKI  => 'MIZUTANI, Tociyuki',
    TODA      => 'Yusuke Toda',
    TOHAE     => 'tohae wakizaka',
    TOKUBASS  => 'Kouji Tominaga',
    TOKUHIROM => 'MATSUNO Tokuhiro',
    TOMBO     => 'Tomoaki Otsuka',
    TOMCHA    => 'Tomokazu Mishima',
    TOMITA    => 'Naoki Tomita',
    TOMOYAMA  => 'Tomohiro Yamashita',
    TOMOYUKI  => 'tomoyuki okino',
    TOMYHERO  => 'Tomohiro Teranishi',
    TONODERA  => 'Takahiro Onodera',
    TOONA     => 'Naoto Ishikawa',
    TOPIA     => 'Tatuya Noda',
    TORICOR   => 'Hiroshi Toriyabe',
    TORITSUYO => 'Tsuyoshi Torii',
    TORU      => 'Toru Hisai',
    TOSHIFJW  => 'Toshimitsu FUJIWARA',
    TOSHIOITO => 'Toshio Ito',
    TPLAYER   => 'Takafumi Sekiguchi',
    TRAVAIL   => 'Tomoyuki SAWA',
    TSAITO    => 'Toshiyuki Saito',
    TSUCCHI   => 'Takuya Tsuchida',
    TSUKAMOTO => 'Makio Tsukamoto',
    TSUNODA   => 'TSUNODA Kazuya',
    TULAMILI  => 'Toshiyuki Shimono',
    TURUGINA  => 'KATOU Akira',
    TWOGMON   => 'Takaaki TSUJIMOTO',
    TXIWASAKI => 'Tooru Iwasaki',
    TYANO     => 'Tatsuhiro YANO',
    TYOSHII   => 'TakanaoYoshii',
    TYPESTER  => 'Daisuke Murase',
    TYRU      => 'Takuya Fujiwara',
    UASI      => 'Tomoki Aonuma',
    UCHIKO    => 'Kousuke Uchiyama',
    UGUTOMO   => 'Tomohiro Horiuchi',
    UINTAHORN => 'Machi Amayadori',
    UMEMOTO   => 'Hajimu Umemoto',
    UMEYUKI   => 'Hiromitsu Ito',
    UMIYOSH   => 'umiyoshi',
    UNLEARNED => 'Takashi Uesugi',
    USUALOMA  => 'Taku Amano',
    UTAANI    => 'Takeshi Ueno',
    UTGWKK    => 'UTAGAWA KIKI',
    VPAM      => 'singo suda',
    WADACHI   => 'Satoshi Wada',
    WAKAPON   => 'ASANO Kazunari',
    WANIJI    => 'Makoto Sasaki',
    WATA      => 'Kouji Watanabe',
    WATANABE  => 'WATANABE Hirofumi',
    WHISKYSHU => 'Shunsuke Usuki',
    WHYWAITA  => 'Nakanishi Kento',
    WKTK      => 'Kenichiro Wakitani',
    WOREMACX  => 'Wore Macx',
    WORTHMINE => 'Yuki Yoshida',
    XAICRON   => 'Yuji Shimada',
    XCEZX     => 'Tsuyoshi Maekawa',
    XOR       => 'Izumi Kawashima',
    YAKEX     => 'Yasutaka ATARASHI',
    YAMAKURA  => 'Kazuhiko Yamakura',
    YAMAMOTO  => 'Ryuzo Yamamoto',
    YAMATO    => 'Toshiyuki Yamato',
    YANA      => 'Toshimitu Yanagisawa',
    YANBE     => 'Yusuke Yanbe',
    YANMAR    => 'Yamamoto Keiichiro',
    YANOTHER  => 'Daisuke (yet another) Maki',
    YANUTETSU => 'satoshi yanuma',
    YAPPO     => 'Kazuhiro Osawa',
    YASU      => 'Yasushi Saito',
    YASUHIRO  => 'Yasuhiro Onishi',
    YAUC      => 'Inoshika cho',
    YAYOHEI   => 'Yohei Yamamoto',
    YIBE      => 'Yuki Ibe',
    YISHINO   => 'Yukio Ishino',
    YOHEIMUTA => 'Yohei Yoshimuta',
    YOITO     => 'Yoshiyuki Ito',
    YOKKUNS   => 'Yohei Sato',
    YONJOUHAN => 'Tetsuya Yamamoto',
    YOSHIAKI  => 'Yoshiaki Shiokawa',
    YOSHIDA   => 'Hironori Yoshida',
    YOSHIMI   => 'Keiji Yoshimi',
    YOSHIOKA  => 'Yuki Yoshioka',
    YOSIZUKA  => 'yukio kusakabe',
    YOSTY     => 'Koji Komatsu',
    YOSUKEF   => 'Yosuke Furukawa',
    YOUPONG   => 'Yusaku NAKAJIMA',
    YOWCOW    => 'Yoko Oyama',
    YSAS      => 'Yasuhiro Sasama',
    YSASAKI   => 'Yoshihiro Sasaki',
    YSHIBATA  => 'Yusuke Shibata',
    YSUZUKI   => 'Yoshihiro SUZUKI',
    YTAKEUCH  => 'TAKEUCHI, Yoji',
    YTURTLE   => 'Satoshi Azuma',
    YUKI      => 'Yuki ANAI',
    YUKINEA   => 'Yuki Nakagawa',
    YUKINOBU  => 'NAGAYASU Yukinobu',
    YUKIO     => 'Yukio Suzuki',
    YUMATSUMO => 'yuya matsumoto',
    YUPUG     => 'Yu Isobe',
    YURYU     => 'Haruka Iwao',
    YUSUKE    => 'Yusuke Shibata',
    YUSUKEBE  => 'Yusuke Wada',
    YUTA      => 'MASUDA Yuta',
    YUTACHI   => 'Yutaka Kuno',
    YUUKI     => 'Yuuki Tsubouchi',
    YUYAW     => 'Yuya Watanabe',
    YUZO      => 'Yuzo Iwasaki',
    YWATASE   => 'Yusuke Watase',
    ZENTOOO   => 'Naosuke Yokoe',
    ZIGOROU   => 'Toru Yamaguchi',
    ZIGUZAGU  => 'Hiroshi Sakai',
    ZOETIN    => 'Yusuke Nozoe',
    ZONCOEN   => 'Kenta Mori',
    ZUQQHINI  => 'Hidetomo Suzuki',
);

1;

__END__

=head1 NAME

Acme::CPANAuthors::Japanese - We are Japanese CPAN authors

=head1 DESCRIPTION

This class provides a hash of Japanese CPAN authors' Pause ID/name to Acme::CPANAuthors.

=head1 MAINTENANCE

If you are a Japanese CPAN author not listed here, send me an email or a pull request to add your own id/name. If you are listed but are not Japanese (or just don't want to be listed), sorry to bother you but tell me via email, IRC, or RT. I'll remove.

=head1 REPOSITORY

https://github.com/charsbar/acme-cpanauthors-japanese

=head1 AUTHOR

Kenichi Ishigaki, E<lt>ishigaki at cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kenichi Ishigaki.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut
